Changes in directory llvm/include/llvm/CodeGen:

MachineInstr.h updated: 1.216 -> 1.217
---
Log message:

Rename findRegisterUseOperand to findRegisterUseOperandIdx to avoid confusion.

---
Diffs of the changes:  (+2 -2)

 MachineInstr.h |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)


Index: llvm/include/llvm/CodeGen/MachineInstr.h
diff -u llvm/include/llvm/CodeGen/MachineInstr.h:1.216 
llvm/include/llvm/CodeGen/MachineInstr.h:1.217
--- llvm/include/llvm/CodeGen/MachineInstr.h:1.216      Wed Apr 25 02:24:13 2007
+++ llvm/include/llvm/CodeGen/MachineInstr.h    Thu Apr 26 13:59:33 2007
@@ -390,10 +390,10 @@
     delete removeFromParent();
   }
 
   /// findRegisterUseOperand() - Returns the operand index that is a use of
   /// the specific register or -1 if it is not found. It further tightening
   /// the search criteria to a use that kills the register if isKill is true.
-  int findRegisterUseOperand(unsigned Reg, bool isKill = false);
+  int findRegisterUseOperandIdx(unsigned Reg, bool isKill = false);
   
   /// findRegisterDefOperand() - Returns the MachineOperand that is a def of
   /// the specific register or NULL if it is not found.
@@ -390,10 +390,10 @@
   }
 
-  /// findRegisterUseOperand() - Returns the operand index that is a use of
+  /// findRegisterUseOperandIdx() - Returns the operand index that is a use of
   /// the specific register or -1 if it is not found. It further tightening
   /// the search criteria to a use that kills the register if isKill is true.



_______________________________________________
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits

Reply via email to